package com.dotsource.intershop.sofort.payment;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import org.apache.axis.utils.StringUtils;

import static com.dotsource.intershop.sofort.payment.SofortConstants.*;

public class SofortPaymentStateModel
{
    private static final List<String> NO_FOLLOWERS = new ArrayList<String>();

    private static final Map<String, List<String>> stateTransitionMap = new HashMap<String, List<String>>();
    
    // this map contains regular transition as well as UNDO transitions
    static {
        stateTransitionMap.put(SHOP_MAPPED_STATE_TEMPORARY, Arrays.asList(SHOP_MAPPED_STATE_ABORTED, SHOP_MAPPED_STATE_CONFIRMED));
        stateTransitionMap.put(SHOP_MAPPED_STATE_ABORTED, NO_FOLLOWERS); // no states after abort and there is no UNDO option
        stateTransitionMap.put(SHOP_MAPPED_STATE_CONFIRMED, Arrays.asList(SHOP_MAPPED_STATE_CHECK_ORDER, SHOP_MAPPED_STATE_NO_CHANGE, SHOP_MAPPED_STATE_PARTIAL_REFUNDED, SHOP_MAPPED_STATE_REFUNDED));
        stateTransitionMap.put(SHOP_MAPPED_STATE_CHECK_ORDER, Arrays.asList(SHOP_MAPPED_STATE_NO_CHANGE, SHOP_MAPPED_STATE_CONFIRMED));
        stateTransitionMap.put(SHOP_MAPPED_STATE_NO_CHANGE, Arrays.asList(SHOP_MAPPED_STATE_PARTIAL_REFUNDED, SHOP_MAPPED_STATE_REFUNDED));
        stateTransitionMap.put(SHOP_MAPPED_STATE_PARTIAL_REFUNDED, Arrays.asList(SHOP_MAPPED_STATE_PARTIAL_REFUNDED, SHOP_MAPPED_STATE_REFUNDED, SHOP_MAPPED_STATE_CONFIRMED));
        stateTransitionMap.put(SHOP_MAPPED_STATE_REFUNDED, Arrays.asList(SHOP_MAPPED_STATE_CONFIRMED, SHOP_MAPPED_STATE_NO_CHANGE));
    }
    
    /**
     * 
     * checks if nextState is a valid follower of currentState
     */
    public static boolean isChangeAllowed(String currentState, String nextState)
    {
        List<String> validNextStates;
        if(StringUtils.isEmpty(currentState) || StringUtils.isEmpty(nextState))
        {
            validNextStates = new ArrayList<String>();
        } else {
            validNextStates = stateTransitionMap.get(currentState);
        }
        return validNextStates.contains(nextState);
    }
}
