package com.dotsource.intershop.sofort.pipelet;

import com.dotsource.intershop.sofort.payment.SofortPaymentService;
import com.intershop.beehive.bts.capi.payment.PaymentTransaction;
import com.intershop.beehive.core.capi.pipeline.Pipelet;
import com.intershop.beehive.core.capi.pipeline.PipeletExecutionException;
import com.intershop.beehive.core.capi.pipeline.PipelineDictionary;
import com.intershop.component.payment.capi.PaymentServiceProxy;

/**
 * Determines the configured mapped state for aborting the payment, checks if
 * the state is allowed to get changed to the new value and updates the state
 * and the payment transaction status. If the state change was successful, the
 * new state will be returned as 'MappedState', otherwise 'MappedState' will
 * contain 'FAILED'.
 */
public class AbortSofortOrderPayment extends Pipelet
{
    public static final String DN_MAPPED_STATE = "MappedState";
    
    /**
     * Constant used to access the pipeline dictionary with key
     * 'PaymentTransaction'
     */
    public static final String DN_PAYMENT_TRANSACTION = "PaymentTransaction";

    /**
     * Constant used to access the pipeline dictionary with key 'Type'
     */
    public static final String DN_TYPE = "RequestType";

    
    @Override
    public int execute(PipelineDictionary dict) throws PipeletExecutionException
    {
        String mappedState;
        
        // lookup 'Type' in pipeline dictionary
        String type = (String)dict.get(DN_TYPE);
        if (null == type)
        {
            throw new PipeletExecutionException("Mandatory input parameter 'RequestType' not available in pipeline dictionary.");
        }

        // lookup 'PaymentTransaction' in pipeline dictionary
        PaymentTransaction paymentTransaction = (PaymentTransaction)dict.get(DN_PAYMENT_TRANSACTION);
        if (null == paymentTransaction)
        {
            throw new PipeletExecutionException("Mandatory input parameter 'PaymentTransaction' not available in pipeline dictionary.");
        }
        
        PaymentServiceProxy proxy = (PaymentServiceProxy)paymentTransaction.getPaymentService();

        SofortPaymentService service = (SofortPaymentService)proxy.getDelegate();

        if (service != null)
        {
            mappedState = service.abortPayment(paymentTransaction, type);
        } else {
            return PIPELET_ERROR;
        }
        dict.put(DN_MAPPED_STATE, mappedState);
        
        return PIPELET_NEXT;
    }

}
