package com.dotsource.intershop.sofort.pipelet;

import com.dotsource.intershop.sofort.payment.SofortPaymentService;
import com.dotsource.intershop.sofort.payment.SofortPaymentStatus;
import com.intershop.beehive.bts.capi.payment.PaymentTransaction;
import com.intershop.beehive.core.capi.pipeline.Pipelet;
import com.intershop.beehive.core.capi.pipeline.PipeletExecutionException;
import com.intershop.beehive.core.capi.pipeline.PipelineDictionary;
import com.intershop.component.payment.capi.PaymentServiceProxy;
import static com.dotsource.intershop.sofort.payment.SofortConstants.*;

/**
 * Determines the configured mapped state, checks if the state is allowed to get
 * changed to the new value and updates the state and the payment transaction
 * status. If the state change was successful, the new state will be returned as
 * 'MappedState', otherwise 'MappedState' will contain 'FAILED'.
 */
public class UpdateSofortOrderPayment extends Pipelet
{

    public static final String DN_MAPPED_STATE = "MappedState";
    
    /**
     * Constant used to access the pipeline dictionary with key
     * 'PaymentTransaction'
     */
    public static final String DN_PAYMENT_TRANSACTION = "PaymentTransaction";

    /**
     * Constant used to access the pipeline dictionary with key 'ResultStatus'
     */
    public static final String DN_REQUEST_TYPE = "RequestType";

    /**
     * Constant used to access the pipeline dictionary with key 'ResultStatus'
     */
    public static final String DN_PAYMENT_STATUS = "SofortPaymentStatus";


    @Override
    public int execute(PipelineDictionary dict) throws PipeletExecutionException
    {
        String mappedState;
        
        // lookup 'SofortPaymentStatus' in pipeline dictionary
        SofortPaymentStatus sofoStatus = (SofortPaymentStatus)dict.get(DN_PAYMENT_STATUS);
        if (null == sofoStatus)
        {
            throw new PipeletExecutionException("Mandatory input parameter 'SofortPaymentStatus' not available in pipeline dictionary.");
        }

        // lookup 'RequestType' in pipeline dictionary
        String requestType = (String)dict.get(DN_REQUEST_TYPE);
        if (null == requestType)
        {
            throw new PipeletExecutionException("Mandatory input parameter 'RequestType' not available in pipeline dictionary.");
        }

        // lookup 'PaymentTransaction' in pipeline dictionary
        PaymentTransaction paymentTransaction = (PaymentTransaction)dict.get(DN_PAYMENT_TRANSACTION);
        if (null == paymentTransaction)
        {
            throw new PipeletExecutionException("Mandatory input parameter 'PaymentTransaction' not available in pipeline dictionary.");
        }
        
        PaymentServiceProxy proxy = (PaymentServiceProxy)paymentTransaction.getPaymentService();

        SofortPaymentService service = (SofortPaymentService)proxy.getDelegate();

        if (service != null)
        {
            mappedState = service.updateStatus(paymentTransaction, sofoStatus, requestType);
        } else {
            return PIPELET_ERROR;
        }
        dict.put(DN_MAPPED_STATE, mappedState);
        
        return PIPELET_NEXT;
    }

}
